==> over_react_codemod-1.3.0.tar.gz: lib/src/component2_suggestors/componentdidupdate_migrator.dart <==
// Copyright 2019 Workiva Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/visitor.dart';
import 'package:codemod/codemod.dart';
import 'package:over_react_codemod/src/component2_suggestors/component2_utilities.dart';

/// Suggestor that adds an optional `snapshot` argument to `componentDidUpdate`.
class ComponentDidUpdateMigrator extends GeneralizingAstVisitor
    with AstVisitingSuggestorMixin
    implements Suggestor {
  final bool allowPartialUpgrades;

  ComponentDidUpdateMigrator({this.allowPartialUpgrades = true});

  @override
  visitMethodDeclaration(MethodDeclaration node) {
    super.visitMethodDeclaration(node);

    ClassDeclaration containingClass = node.parent;

    if (!allowPartialUpgrades &&
        !fullyUpgradableToComponent2(containingClass)) {
      return;
    }

    if (extendsComponent2(containingClass)) {
      if (node.name.name == 'componentDidUpdate') {
        if (node.parameters.parameters.length == 2) {
          yieldPatch(node.parameters.rightParenthesis.offset,
              node.parameters.rightParenthesis.offset, ', [snapshot]');
        }
      }
    }
  }
}

==> over_react_codemod-1.4.1.tar.gz: lib/src/component2_suggestors/componentdidupdate_migrator.dart <==
// Copyright 2019 Workiva Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:analyzer/dart/ast/ast.dart';
import 'package:analyzer/dart/ast/visitor.dart';
import 'package:codemod/codemod.dart';
import 'package:over_react_codemod/src/component2_suggestors/component2_utilities.dart';

/// Suggestor that adds an optional `snapshot` argument to `componentDidUpdate`.
class ComponentDidUpdateMigrator extends GeneralizingAstVisitor
    with AstVisitingSuggestorMixin
    implements Suggestor {
  final bool allowPartialUpgrades;
  final bool shouldUpgradeAbstractComponents;

  ComponentDidUpdateMigrator({
    this.allowPartialUpgrades = true,
    this.shouldUpgradeAbstractComponents = false,
  });

  @override
  visitMethodDeclaration(MethodDeclaration node) {
    super.visitMethodDeclaration(node);

    ClassDeclaration containingClass = node.parent;

    if ((!allowPartialUpgrades &&
            !fullyUpgradableToComponent2(containingClass)) ||
        (!shouldUpgradeAbstractComponents &&
            canBeExtendedFrom(containingClass))) {
      return;
    }

    if (extendsComponent2(containingClass)) {
      if (node.name.name == 'componentDidUpdate') {
        if (node.parameters.parameters.length == 2) {
          yieldPatch(node.parameters.rightParenthesis.offset,
              node.parameters.rightParenthesis.offset, ', [snapshot]');
        }
      }
    }
  }
}
